# CENTER-TBI six-months GOSe-Outcome Imputation

This repository contains the entire source code to reproduce the imputation for
the six-months GOSe in CENTER-TBI.



## Prerequisites


### Data Access

To reproduce the analysis, access to the CENTER-TBI 'Neurobot' database at
https://center-tbi.incf.org and a personal access toke to the curl API
is required.
For information on how to get dat access, see https://www.center-tbi.eu/data.


### Software dependencies

The workflow assumes a linux command line.
To facilitate reproducibility, a 
[docker container](https://cloud.docker.com/u/kkmann/repository/docker/kkmann/gose-6mo-imputation)
container with all software dependencies
(R packages etc.) is provided [here]().
The workflow itself is automated using [snakemake]() 5.2.1.

To fully leverage the container and snakemake workflow, the following software
dependencies must be available:

* [python](https://www.python.org/download/releases/3.5.1/) 3.5.1 (higher versions might work as well) 
* [snakemake](https://snakemake.readthedocs.io/en/stable/getting_started/installation.html) version 5.2.1 (higher versions will work as well)
* [singularity](https://www.sylabs.io/guides/2.6/user-guide/index.html) 2.6.0 (higher versions might work as well)



## How-To

The download script requires the neurobot user name and the personal API key
to be stored in the environment variables `NEUROBOT_USR` `NEUROBOT_API`, 
respectively, i.e.
```bash
export NEUROBOT_USR=[my-neurobot-username]
export NEUROBOT_API=[my-neurobot-api-key]
```


### Execute Workflow on Desktop

The workflow can be executed on a potent desktop machine although a cluster
execution is recommended (cf. blow).
```bash
./singularity manuscript_v1_1
./singularity impute_msm_v1_1
```

All output is written to `output/`.
Depending on the number of cores and available RAM, 
the cross-validated model comparison may take several days (3+) to complete.


### Execute Workflow on Cluster

Cluster execution requires slightly more 
[configuration](https://github.com/kkmann/center-6mo-gose-imputation/blob/master/cluster.json)
and assumes existence of a slurm cluster.
Simply modify the `cluster.json` accordingly and execute
```bash
./singularity_slurm manuscript_v1_1
./singularity_slurm impute_msm_v1_1
```
